Matrix License — PyCogent v1.3 documentation

### Navigation

- index
- next |
- previous |
- PyCogent v1.3 documentation »
- Licenses and disclaimer »

# Matrix License

This is not really a license per se, but a copy of the e-mail from Ziheng Yang giving us permission to include his source code in the distribution. Questions regarding the license specifics for this module should be addressed to Ziheng at the e-mail address below.

Gavin Huttley 24/06/2003

    ==================================================================

    Subject: Re: Matrix exp
    Date: Wednesday, 28 May 2003 5:48 PM
    From: Ziheng Yang <z.yang@ucl.ac.uk>
    To: Gavin Huttley <gavin.huttley@anu.edu.au>

    Hi Gavin,

    You have my permission to use the codes for matrix exponential and eigen
    calculation.  I won't take any responsibility for any errors in the source
    code.

    Are you using the code for a symmetrical real matrix (or for a
    reversible-process rate matrix) as well?

    Best,
    Ziheng

    At 16:46 28/05/2003 +1000, Gavin Huttley wrote:
    >Hi Ziheng:
    >
    >I'm following up from my previous request for instructions on how to use
    >your matrix exponential code. It helped us to solve our problem (which were
    >simple coding errors on my part). I'd now like to get your permission to
    >distribute the same matrix exponential source-code with our software.
    >
    >A bit of background on the software. It is basically molecular evolutionary
    >modelling software, in the spirit of PAML, PAL and HYPHY. It is being
    >developed with the aim of serving as both a development toolkit and
    >evolutionary modelling package. We have implemented the software as a module
    >to the scripting language Python. The computationally intensive bits are
    >written in either C or C++, with a bit of Fortran thrown in (although we aim
    >to recode that optimiser in one of the other languages when we get time).
    >Aside from the mentioned Fortran code and your and Tiang Wen's eigen code,
    >everything has been written from scratch. We intend to release an alpha
    >version of the software under the GPL sometime in the next month or so (I'll
    >be presenting a poster on it at ISMB in Brisbane next month). At present the
    >software has no real name (although it's called EVOLVE in the poster
    >abstract).
    >
    >look forward to hearing from you.
    >
    >cheers,
    >
    >gavin

### Navigation

- index
- next |
- previous |
- PyCogent v1.3 documentation »
- Licenses and disclaimer »